@@ -9,7 +9,7 @@ void Scanner::testExitValue(std::string const &cmd,
             "NOTE: this is the literal text of the executed command. "
                             "Maybe a typo?" << endl;
 
-    if (d_testExitValue && A2x(s_exitValue[1]) != 0)
+    if (d_testExitValue && stoul(s_exitValue[1]) != 0)
         d_reporter.error() << 
             "Program terminated due to non-zero exit value for\n" <<
             *d_cmdIterator << " (" << exitStr << ")" << endl;
